@@ -1,4 +1,4 @@
-/* $ID: fastmatrix_API.h, last updated 2023-02-24, F.Osorio */
+/* $ID: fastmatrix_API.h, last updated 2025-10-14, F.Osorio */
 
 #ifndef FASTMATRIX_API_H
 #define FASTMATRIX_API_H
@@ -210,31 +210,6 @@ void BLAS3_trsm(double alpha, double *a, int lda, int nrow, int ncol, char *side
   fun(alpha, a, lda, nrow, ncol, side, uplo, trans, diag, y, ldy);
 }
 
-/* ========================================================================== *
- * OMO: external API
- * ========================================================================== */
-
-double OMO_blinf(double *a, int lda, int n, int p, double *x, double *y) {
-  static double(*fun)(double *, int, int, int, double *, double *) = NULL;
-  if (fun == NULL)
-    fun = (double(*)(double *, int, int, int, double *, double *)) R_GetCCallable("fastmatrix", "OMO_blinf");
-  return fun(a, lda, n, p, x, y);
-}
-
-double OMO_quadf(double *a, int lda, int n, double *x) {
-  static double(*fun)(double *, int, int, double *) = NULL;
-  if (fun == NULL)
-    fun = (double(*)(double *, int, int, double *)) R_GetCCallable("fastmatrix", "OMO_quadf");
-  return fun(a, lda, n, x);
-}
-
-void OMO_murrv(double *y, double *a, int lda, int n, int p, double *x, int *info) {
-  static void(*fun)(double *, double *, int, int, int, double *, int *) = NULL;
-  if (fun == NULL)
-    fun = (void(*)(double *, double *, int, int, int, double *, int *)) R_GetCCallable("fastmatrix", "OMO_murrv");
-  fun(y, a, lda, n, p, x, info);
-}
-
 /* ========================================================================== *
  * operations on vectors: external API
  * ========================================================================== */
@@ -448,6 +423,15 @@ void FM_LQ_decomp(double *mat, int ldmat, int nrow, int ncol, double *lqaux, int
   fun(mat, ldmat, nrow, ncol, lqaux, info);
 }
 
+void FM_schur_decomp(double *a, int lda, int n, int task, double *re, double *im, double *v, int ldv, int *info) {
+  static void(*fun)(double *, int, int, int, double *, double *, double *, 
+                    int, int *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, int, int, double *, double *, double *, 
+                   int, int *)) R_GetCCallable("fastmatrix", "FM_schur_decomp");
+  fun(a, lda, n, task, re, im, v, ldv, info);
+}
+
 void FM_svd_decomp(double *mat, int ldmat, int nrow, int ncol, double *u, int ldu, double *d, double *v, int ldv, int job, int *info) {
   static void(*fun)(double *, int, int, int, double *, int, double *, double *,
                     int, int, int *) = NULL;
@@ -636,6 +620,17 @@ void FM_mahal_distances(double *x, int n, int p, double *center, double *cov, in
   fun(x, n, p, center, cov, inverted, distances);
 }
 
+/* ========================================================================== *
+ * Wilson-Hilferty transformation: external API
+ * ========================================================================== */
+
+void FM_WH_gamma(double *y, int n, double shape, double scale, double *z) {
+  static void(*fun)(double *, int, double, double, double *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, double, double, double *)) R_GetCCallable("fastmatrix", "FM_WH_gamma");
+  fun(y, n, shape, scale, z);
+}
+
 void FM_WH_chisq(double *distances, int n, int p, double *z) {
   static void(*fun)(double *, int, int, double *) = NULL;
   if (fun == NULL)
@@ -650,6 +645,13 @@ void FM_WH_F(double *distances, int n, int p, double eta, double *z) {
   fun(distances, n, p, eta, z);
 }
 
+void FM_WH_Laplace(double *distances, int n, int p, double *z) {
+  static void(*fun)(double *, int, int, double *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, int, double *)) R_GetCCallable("fastmatrix", "FM_WH_Laplace");
+  fun(distances, n, p, z);
+}
+
 /* ========================================================================== *
  * Products: external API
  * ========================================================================== */
@@ -714,6 +716,13 @@ void FM_mean_and_var(double *x, int nobs, double *mean, double *var) {
   fun(x, nobs, mean, var);
 }
 
+void FM_mediancenter(double *x, int n, int p, double *median, int *iter) {
+  static void(*fun)(double *, int, int, double *, int *) = NULL;
+  if (fun == NULL)
+    fun = (void(*)(double *, int, int, double *, int *)) R_GetCCallable("fastmatrix", "FM_mediancenter");
+  fun(x, n, p, median, iter);
+}
+
 void FM_moments(double *x, int nobs, double *mean, double *s2, double *s3, double *s4) {
   static void(*fun)(double *, int, double *, double *, double *, double *) = NULL;
   if (fun == NULL)
